@@ -21,8 +21,8 @@ async def message(sid, data):
 
 
 @eio.on('disconnect')
-def disconnect(sid):
-    print('disconnect ', sid)
+def disconnect(sid, reason):
+    print('disconnect ', sid, reason)
 
 
 if __name__ == '__main__':
