@@ -16,6 +16,18 @@ from engineio import payload
 
 
 class TestAsyncClient:
+    def mock_queue(self, client):
+        client.queue = mock.MagicMock()
+        client.queue_empty = RuntimeError
+        client.queue.get_nowait.side_effect = client.queue_empty
+        client.queue.get = mock.AsyncMock()
+        client.queue.put = mock.AsyncMock()
+        client.queue.join = mock.AsyncMock()
+
+    @staticmethod
+    def mock_ws_timeout(ws_close):
+        return ws_close
+
     async def test_is_asyncio_based(self):
         c = async_client.AsyncClient()
         assert c.is_asyncio_based()
@@ -143,9 +155,7 @@ class TestAsyncClient:
         base_client.connected_clients.append(c)
         c.state = 'connected'
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
-        c.queue.join = mock.AsyncMock()
+        self.mock_queue(c)
         c.read_loop_task = mock.AsyncMock()()
         c.ws = mock.MagicMock()
         c.ws.close = mock.AsyncMock()
@@ -162,9 +172,7 @@ class TestAsyncClient:
         base_client.connected_clients.append(c)
         c.state = 'connected'
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
-        c.queue.join = mock.AsyncMock()
+        self.mock_queue(c)
         c.read_loop_task = mock.AsyncMock()()
         c.ws = mock.MagicMock()
         c.ws.close = mock.AsyncMock()
@@ -181,9 +189,7 @@ class TestAsyncClient:
         base_client.connected_clients.append(c)
         c.state = 'connected'
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
-        c.queue.join = mock.AsyncMock()
+        self.mock_queue(c)
         c.read_loop_task = mock.AsyncMock()()
         c.ws = mock.MagicMock()
         c.ws.close = mock.AsyncMock()
@@ -197,9 +203,7 @@ class TestAsyncClient:
         base_client.connected_clients.append(c)
         c.state = 'connected'
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
-        c.queue.join = mock.AsyncMock()
+        self.mock_queue(c)
         c.read_loop_task = mock.AsyncMock()()
         c.ws = mock.MagicMock()
         c.ws.close = mock.AsyncMock()
@@ -225,7 +229,7 @@ class TestAsyncClient:
     async def test_create_queue(self):
         c = async_client.AsyncClient()
         q = c.create_queue()
-        with pytest.raises(q.Empty):
+        with pytest.raises(c.queue_empty):
             q.get_nowait()
 
     async def test_create_event(self):
@@ -500,6 +504,8 @@ class TestAsyncClient:
         assert c in base_client.connected_clients
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_connection_failed(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -541,6 +547,8 @@ class TestAsyncClient:
         )
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_upgrade_failed(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -568,6 +576,8 @@ class TestAsyncClient:
             await c.connect('http://foo', transports=['websocket'])
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_connection_successful(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -649,6 +659,8 @@ class TestAsyncClient:
         assert kwargs['ssl'].verify_mode == ssl.CERT_NONE
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_connection_with_cookies(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -682,6 +694,8 @@ class TestAsyncClient:
         )
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_connection_with_cookie_header(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -714,10 +728,12 @@ class TestAsyncClient:
             timeout=5,
         )
         c.http.cookie_jar.update_cookies.assert_called_once_with(
-            {'key': 'value', 'key2': 'value2', 'key3': '"value3="'}
+            {'key': 'value', 'key2': 'value2', 'key3': 'value3='}
         )
 
     @mock.patch('engineio.client.time.time', return_value=123.456)
+    @mock.patch('engineio.async_client.aiohttp.ClientWSTimeout',
+                new=mock_ws_timeout)
     async def test_websocket_connection_with_cookies_and_headers(self, _time):
         c = async_client.AsyncClient()
         c.http = mock.MagicMock(closed=False)
@@ -1014,8 +1030,7 @@ class TestAsyncClient:
         c.ping_timeout = 5
         c.state = 'connected'
         c.base_url = 'http://foo'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c._send_request = mock.AsyncMock(return_value=None)
         c._trigger_event = mock.AsyncMock()
         c.write_loop_task = mock.AsyncMock()()
@@ -1036,8 +1051,7 @@ class TestAsyncClient:
         c.ping_timeout = 5
         c.state = 'connected'
         c.base_url = 'http://foo'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c._send_request = mock.AsyncMock()
         c._send_request.return_value.status = 400
         c.write_loop_task = mock.AsyncMock()()
@@ -1055,8 +1069,7 @@ class TestAsyncClient:
         c.ping_timeout = 60
         c.state = 'connected'
         c.base_url = 'http://foo'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c._send_request = mock.AsyncMock()
         c._send_request.return_value.status = 200
         c._send_request.return_value.read = mock.AsyncMock(return_value=b'foo')
@@ -1074,8 +1087,7 @@ class TestAsyncClient:
         c.ping_timeout = 5
         c.state = 'connected'
         c.base_url = 'http://foo'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c._send_request = mock.AsyncMock()
         c._send_request.side_effect = [
             mock.MagicMock(
@@ -1114,8 +1126,7 @@ class TestAsyncClient:
         c.ping_timeout = 2
         c.base_url = 'ws://foo'
         c.state = 'connected'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c.ws = mock.MagicMock()
         c.ws.receive = mock.AsyncMock(side_effect=asyncio.TimeoutError())
         c.write_loop_task = mock.AsyncMock()()
@@ -1129,8 +1140,7 @@ class TestAsyncClient:
         c.ping_timeout = 2
         c.base_url = 'ws://foo'
         c.state = 'connected'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c.ws = mock.MagicMock()
         c.ws.receive = mock.AsyncMock(
             side_effect=aiohttp.client_exceptions.ServerDisconnectedError()
@@ -1146,8 +1156,7 @@ class TestAsyncClient:
         c.ping_timeout = 2
         c.base_url = 'ws://foo'
         c.state = 'connected'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c.ws = mock.MagicMock()
         c.ws.receive = mock.AsyncMock(side_effect=ValueError)
         c.write_loop_task = mock.AsyncMock()()
@@ -1161,8 +1170,7 @@ class TestAsyncClient:
         c.ping_timeout = 2
         c.base_url = 'ws://foo'
         c.state = 'connected'
-        c.queue = mock.MagicMock()
-        c.queue.put = mock.AsyncMock()
+        self.mock_queue(c)
         c.ws = mock.MagicMock()
         c.ws.receive = mock.AsyncMock(
             side_effect=[
@@ -1188,7 +1196,7 @@ class TestAsyncClient:
         c.state = 'connected'
         c.ping_interval = 1
         c.ping_timeout = 2
-        c.queue = mock.MagicMock()
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(return_value=None)
         await c._write_loop()
         c.queue.task_done.assert_called_once_with()
@@ -1199,9 +1207,8 @@ class TestAsyncClient:
         c.state = 'connected'
         c.ping_interval = 1
         c.ping_timeout = 2
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
-        c.queue.get = mock.AsyncMock(side_effect=RuntimeError)
+        self.mock_queue(c)
+        c.queue.get = mock.AsyncMock(side_effect=c.queue_empty)
         await c._write_loop()
         c.queue.get.assert_awaited_once_with()
 
@@ -1212,15 +1219,14 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=RuntimeError)
+        c.queue.get_nowait = mock.MagicMock(side_effect=c.queue_empty)
         c._send_request = mock.AsyncMock()
         c._send_request.return_value.status = 200
         await c._write_loop()
@@ -1243,19 +1249,18 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
         c.queue.get_nowait = mock.MagicMock(
             side_effect=[
                 packet.Packet(packet.PING),
                 packet.Packet(packet.NOOP),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
         c._send_request = mock.AsyncMock()
@@ -1284,12 +1289,11 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
         c.queue.get_nowait = mock.MagicMock(
@@ -1321,12 +1325,11 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[packet.Packet(packet.MESSAGE, {'foo': 'bar'})]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=[RuntimeError])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[c.queue_empty])
         c._send_request = mock.AsyncMock(return_value=None)
         await c._write_loop()
         assert c.queue.task_done.call_count == 1
@@ -1349,12 +1352,11 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'polling'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[packet.Packet(packet.MESSAGE, {'foo': 'bar'})]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=[RuntimeError])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[c.queue_empty])
         c._send_request = mock.AsyncMock()
         c._send_request.return_value.status = 500
         await c._write_loop()
@@ -1378,15 +1380,14 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=[RuntimeError])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[c.queue_empty])
         c.ws = mock.MagicMock()
         c.ws.send_str = mock.AsyncMock()
         await c._write_loop()
@@ -1400,19 +1401,18 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
         c.queue.get_nowait = mock.MagicMock(
             side_effect=[
                 packet.Packet(packet.PING),
                 packet.Packet(packet.NOOP),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
         c.ws = mock.MagicMock()
@@ -1430,12 +1430,11 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
-            side_effect=[packet.Packet(packet.MESSAGE, b'foo'), RuntimeError]
+            side_effect=[packet.Packet(packet.MESSAGE, b'foo'), c.queue_empty]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=[RuntimeError])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[c.queue_empty])
         c.ws = mock.MagicMock()
         c.ws.send_bytes = mock.AsyncMock()
         await c._write_loop()
@@ -1449,15 +1448,14 @@ class TestAsyncClient:
         c.ping_interval = 1
         c.ping_timeout = 2
         c.current_transport = 'websocket'
-        c.queue = mock.MagicMock()
-        c.queue.Empty = RuntimeError
+        self.mock_queue(c)
         c.queue.get = mock.AsyncMock(
             side_effect=[
                 packet.Packet(packet.MESSAGE, {'foo': 'bar'}),
-                RuntimeError,
+                c.queue_empty,
             ]
         )
-        c.queue.get_nowait = mock.MagicMock(side_effect=[RuntimeError])
+        c.queue.get_nowait = mock.MagicMock(side_effect=[c.queue_empty])
         c.ws = mock.MagicMock()
         c.ws.send_str = mock.AsyncMock(
             side_effect=aiohttp.client_exceptions.ServerDisconnectedError()
